@@ -1,11 +1,7 @@
 # -*- perl -*-
 
 package Bundle::Image::Info::XBM;
-
-use strict;
-use vars qw($VERSION);
-$VERSION = '0.02';
-
+$VERSION = '0.01';
 1;
 
 __END__
@@ -16,8 +12,6 @@ Bundle::Image::Info::XBM - XBM (X11 bitmap) support for Image::Info
 
 =head1 SYNOPSIS
 
-=for test_synopsis BEGIN { die "SKIP: shell code\n"; }
-
  perl -MCPAN -e 'install Bundle::Image::Info::XBM'
 
 =head1 CONTENTS
